@@ -115,8 +115,17 @@ class SubprocessFactoryImpl:
                         __name__, self.__class__.__name__, key
                     )
                 )
-        self._terminal_stdout = tempfile.SpooledTemporaryFile(512000)
-        self._terminal_stderr = tempfile.SpooledTemporaryFile(512000)
+        self._terminal_stdout = tempfile.SpooledTemporaryFile(512000, buffering=0)
+        self._terminal_stderr = tempfile.SpooledTemporaryFile(512000, buffering=0)
+        if platform.is_windows():
+            # Windows does not support closing FDs
+            close_fds = False
+        elif platform.is_freebsd() and sys.version_info < (3, 9):
+            # Closing FDs in FreeBSD before Py3.9 can be slow
+            #   https://bugs.python.org/issue38061
+            close_fds = False
+        else:
+            close_fds = True
         self._terminal = subprocess.Popen(
             cmdline,
             stdout=self._terminal_stdout,
@@ -124,7 +133,7 @@ class SubprocessFactoryImpl:
             shell=False,
             cwd=self.factory.cwd,
             universal_newlines=True,
-            close_fds=platform.is_windows() is False,
+            close_fds=close_fds,
         )
         # Reset the previous _terminal_result if set
         self._terminal_result = None
@@ -220,22 +229,10 @@ class SubprocessFactoryImpl:
                 )
             self._terminal_stderr.close()
         try:
-            log_message = "Terminated {}.".format(self.factory)
-            if stdout or stderr:
-                log_message += " Process Output:"
-                if stdout:
-                    log_message += "\n>>>>> STDOUT >>>>>\n{}\n<<<<< STDOUT <<<<<".format(
-                        stdout.strip()
-                    )
-                if stderr:
-                    log_message += "\n>>>>> STDERR >>>>>\n{}\n<<<<< STDERR <<<<<".format(
-                        stderr.strip()
-                    )
-                log_message += "\n"
-            log.info(log_message)
             self._terminal_result = ProcessResult(
                 self._terminal.returncode, stdout, stderr, cmdline=self._terminal.args
             )
+            log.info(self._terminal_result)
             return self._terminal_result
         finally:
             self._terminal = None
@@ -371,7 +368,6 @@ class ProcessFactory(SubprocessFactoryBase):
     """
 
     default_timeout = attr.ib()
-    _terminal_timeout_set_explicitly = attr.ib(repr=False, init=False, default=False)
 
     @default_timeout.default
     def _set_default_timeout(self):
@@ -389,8 +385,6 @@ class ProcessFactory(SubprocessFactoryBase):
         # We set the _terminal_timeout attribute while calling build_cmdline in case it needs
         # access to that information to build the command line
         self.impl._terminal_timeout = _timeout or self.default_timeout
-        self._terminal_timeout_set_explicitly = _timeout is not None
-        timeout_expire = time.time() + self.impl._terminal_timeout
         timmed_out = False
         try:
             self.impl.run(*args, **kwargs)
@@ -936,28 +930,31 @@ class SaltCliFactory(SaltFactory, ProcessFactory):
                 if arg.startswith("--timeout="):
                     # Let's actually change the _terminal_timeout value which is used to
                     # calculate when the run() method should actually timeout
-                    if self._terminal_timeout_set_explicitly is False:
-                        salt_cli_timeout = arg.split("--timeout=")[-1]
-                        try:
-                            self.impl._terminal_timeout = int(salt_cli_timeout) + 5
-                        except ValueError:
-                            # Not a number? Let salt do it's error handling
-                            pass
+                    try:
+                        salt_cli_timeout = int(arg.split("--timeout=")[-1])
+                    except ValueError:
+                        # Not a number? Let salt do it's error handling
+                        break
+                    if salt_cli_timeout >= self.impl._terminal_timeout:
+                        self.impl._terminal_timeout = int(salt_cli_timeout) + 5
                     break
                 if salt_cli_timeout_next:
-                    if self._terminal_timeout_set_explicitly is False:
-                        try:
-                            self.impl._terminal_timeout = int(arg) + 5
-                        except ValueError:
-                            # Not a number? Let salt do it's error handling
-                            pass
+                    try:
+                        salt_cli_timeout = int(arg)
+                    except ValueError:
+                        # Not a number? Let salt do it's error handling
+                        break
+                    if salt_cli_timeout >= self.impl._terminal_timeout:
+                        self.impl._terminal_timeout = int(salt_cli_timeout) + 5
                     break
                 if arg == "-t" or arg.startswith("--timeout"):
                     salt_cli_timeout_next = True
                     continue
             else:
+                # Always shave off 5 seconds to the passed --timeout argument so that the salt command times out
+                # before the terminal does
                 salt_cli_timeout = self.impl._terminal_timeout
-                if salt_cli_timeout and self._terminal_timeout_set_explicitly is False:
+                if salt_cli_timeout:
                     # Shave off a few seconds so that the salt command times out before the terminal does
                     salt_cli_timeout -= 5
                 if salt_cli_timeout:
@@ -1120,16 +1117,9 @@ class SystemdSaltDaemonFactoryImpl(DaemonFactoryImpl):
         )
         stdout = result.stdout.strip()
         stderr = result.stderr.strip()
-        log_message = "Completed Command: {}".format(result.args)
-        if stdout or stderr:
-            log_message += " Process Output:"
-            if stdout:
-                log_message += "\n>>>>> STDOUT >>>>>\n{}\n<<<<< STDOUT <<<<<".format(stdout.strip())
-            if stderr:
-                log_message += "\n>>>>> STDERR >>>>>\n{}\n<<<<< STDERR <<<<<".format(stderr.strip())
-            log_message += "\n"
-        log.info(log_message)
-        return ProcessResult(result.returncode, stdout, stderr, cmdline=result.args)
+        process_result = ProcessResult(result.returncode, stdout, stderr, cmdline=result.args)
+        log.info(process_result)
+        return process_result
 
     def start(self, *extra_cli_arguments, max_start_attempts=None, start_timeout=None):
         try:
@@ -1187,20 +1177,8 @@ class SystemdSaltDaemonFactoryImpl(DaemonFactoryImpl):
         ret = self.internal_run("journalctl", "--no-pager", "-u", self.get_service_name())
         stderr = ret.stdout
         try:
-            log_message = "Terminated {}.".format(self.factory)
-            if stdout or stderr:
-                log_message += " Process Output:"
-                if stdout:
-                    log_message += "\n>>>>> STDOUT >>>>>\n{}\n<<<<< STDOUT <<<<<".format(
-                        stdout.strip()
-                    )
-                if stderr:
-                    log_message += "\n>>>>> STDERR >>>>>\n{}\n<<<<< STDERR <<<<<".format(
-                        stderr.strip()
-                    )
-                log_message += "\n"
-            log.info(log_message)
             self._terminal_result = ProcessResult(exitcode, stdout, stderr, cmdline=cmdline)
+            log.info(self._terminal_result)
             return self._terminal_result
         finally:
             self._terminal = None
@@ -1376,7 +1354,7 @@ class SaltDaemonFactory(SaltFactory, DaemonFactory):
             if not check_events:
                 break
             check_events -= {
-                (event.master_id, event.tag)
+                (event.daemon_id, event.tag)
                 for event in self.event_listener.get_events(check_events, after_time=started_at)
             }
             if check_events:
